| Endpoint | R Documentation |
Endpoint object, storing HTTP client object and handling requests and responses to API
Formatted URL
Returns response after validating
Response object
STATUS_CODE_SUCCESS(list) Contains successful response codes
HttpClient(crul::HttpClient) Connection object
STATUS_CODE_SUCCESS(list) Contains successful response codes
HttpClient(crul::HttpClient) Connection object
new()Create an endpoint
Endpoint$new(connection)
connection(crul::HttpClient) Connection object
clone()The objects of this class are cloneable with this method.
Endpoint$clone(deep = FALSE)
deepWhether to make a deep clone.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.